==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PrometheusBuilder extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.Prometheus,io.fabric8.openshift.api.model.monitoring.v1.PrometheusBuilder>{
  public PrometheusBuilder() {
    this(false);
  }
  public PrometheusBuilder(java.lang.Boolean validationEnabled) {
    this(new Prometheus(), validationEnabled);
  }
  public PrometheusBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Prometheus(), validationEnabled);
  }
  public PrometheusBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Prometheus instance) {
    this(fluent, instance, false);
  }
  public PrometheusBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Prometheus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PrometheusBuilder(io.fabric8.openshift.api.model.monitoring.v1.Prometheus instance) {
    this(instance,false);
  }
  public PrometheusBuilder(io.fabric8.openshift.api.model.monitoring.v1.Prometheus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.Prometheus build() {
    Prometheus buildable = new Prometheus(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PrometheusBuilder that = (PrometheusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.1.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PrometheusBuilder extends PrometheusFluentImpl<PrometheusBuilder> implements VisitableBuilder<Prometheus,PrometheusBuilder>{
  public PrometheusBuilder() {
    this(false);
  }
  public PrometheusBuilder(Boolean validationEnabled) {
    this(new Prometheus(), validationEnabled);
  }
  public PrometheusBuilder(PrometheusFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusBuilder(PrometheusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Prometheus(), validationEnabled);
  }
  public PrometheusBuilder(PrometheusFluent<?> fluent,Prometheus instance) {
    this(fluent, instance, false);
  }
  public PrometheusBuilder(PrometheusFluent<?> fluent,Prometheus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PrometheusBuilder(Prometheus instance) {
    this(instance,false);
  }
  public PrometheusBuilder(Prometheus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  PrometheusFluent<?> fluent;
  Boolean validationEnabled;
  public Prometheus build() {
    Prometheus buildable = new Prometheus(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
